ml.evaluation package
=====================

Submodules
----------

ml.evaluation.classification module
-----------------------------------

.. automodule:: ml.evaluation.classification
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ml.evaluation
   :members:
   :undoc-members:
   :show-inheritance:
